/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Fasterfox.
 *
 * The Initial Developer of the Original Code is
 * Tony Gentilcore.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  See readme.txt
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

// create arrays of the form elements for use in the code below
var _elementIDs =	["ff_presets", "ff_enhancedPrefetching","ff_pipelining","ff_pipeliningFirstRequest","ff_proxyPipelining",
					"ff_pageLoadTimer", "ff_cacheMemoryCapacity","ff_cacheDiskCapacity","ff_maxConnections", 
					"ff_maxConnectionsPerServer", "ff_maxPersistentConnectionsPerServer","ff_maxPersistentConnectionsPerProxy","ff_maxPipeliningRequests", 
					"ff_initialPaintDelay", "ff_disablePluginPopups", "ff_dnsCacheExpiration", "ff_dnsCacheEntries", 
					"ff_uiSubmenuDelay"];

// Presets: [Default, Good Net Citizen, Optimized, Turbo Charged]
// ff_presets[n] corresponds to _elementIDs[n+1]
var ff_presets =	new Array([false, false, true, true], [false, false, true, true], [false, false, true, true], [false, false, true, true],
					[true, true, true, true], [-1, 65536, 65536, 65536], [50000, 76800, 76800, 76800], [24, 24, 40, 48], 
					[8, 8, 16, 24], [2, 2, 6, 8], [4, 4, 12, 16], [4, 4, 6, 8], 
					[250, 0, 0, 0], [0, 2, 2, 2], [60, 3600, 3600, 3600], [20, 512, 512, 512], 
					[300, 50, 50, 50]);
				
/*
 * load all preferences into a PrefWindowIV dialog
 * this makes use of the old PrefWindowIV callbacks and functions
 */
function Startup() {
	
	// show or hide the advanced tabs for Prefs IV	
	// and open the most recently viewed tab if custom is selected
	// Special thanks to Bryan Burke for this bug fix (see bug 11795)
	if(parent.hPrefWindow.getPref("int", "extensions.fasterfox.preset", 3) == 4) {
		document.getElementById("ff_tabs").selectedIndex = parent.hPrefWindow.getPref("int", "extensions.fasterfox.lastTab", 0);
		FF_displayTabs(true);
	} else {
		document.getElementById("ff_tabs").selectedIndex = 0;
		FF_displayTabs(false);
	}
	
	// check or uncheck the popups checkbox based on the preference setting
	if(parent.hPrefWindow.getPref("int", "privacy.popups.disable_from_plugins", 2) == 2) {
		document.getElementById('ff_disablePluginPopupsCheckbox').checked=true;
	} else {
		document.getElementById('ff_disablePluginPopupsCheckbox').checked=false;
	}

	// register the PrefWindowIV OK-button callback
  	parent.hPrefWindow.registerOKCallbackFunc(FF_onOK);

}

/*
 * save all preferences from an old PrefWindowIV dialog
 */
function FF_onOK() {
	
	// save the most recently viewed tab
	try {
		parent.hPrefWindow.setPref("int", "extensions.fasterfox.lastTab", document.getElementById('ff_tabs').selectedIndex);
	} catch(e){}
	
	return true;	
}

function FF_setPreset(presetNumber) {
    var i, pref, element;
    // Set the form elements to the proper preset
	for (i = 0; i < ff_presets.length; i++) {
		element = document.getElementById(_elementIDs[i+1]);
  		pref = document.getElementById(element.getAttribute("preference"));
  		if(pref) {
	  		// Pref V
	  		pref.value = ff_presets[i][presetNumber];
  		} else {
	  		// Pref IV
	  		//alert(element.getAttribute("prefstring") + ' = ' + ff_presets[i][presetNumber]);	  		
	  		parent.hPrefWindow.setPref(element.getAttribute("preftype"), element.getAttribute("prefstring"), ff_presets[i][presetNumber]);
	  		if (element.getAttribute("preftype") == "bool")
	  			element.checked = ff_presets[i][presetNumber];
	  		else
	  			element.value = ff_presets[i][presetNumber];
  		}
  	}
}

/*
 * Accepts a boolean value which determines whether
 * all tabs should be shown or hidden
 *
 * true = display all tabs
 * false = hide all tabs
 */
function FF_displayTabs(show) {
    
	// hide or show the tabs
	document.getElementById("ff_tabs").setAttribute("hidden", !show);
	
}
